pub(crate) struct MoveContext<'a> {
index: Cell<Option<u32>>,
pub(crate) old_parent: Option<&'a Node>,
prev_sibling: Option<&'a Node>,
pub(crate) next_sibling: Option<&'a Node>,
}Expand description
The context of the moving from a tree of a node when one of its inclusive ancestors is moved.
Fields
index: Cell<Option<u32>>The index of the inclusive ancestor that was moved.
old_parent: Option<&'a Node>The old parent, if any, of the inclusive ancestor that was moved.
prev_sibling: Option<&'a Node>The previous sibling of the inclusive ancestor that was moved.
next_sibling: Option<&'a Node>The next sibling of the inclusive ancestor that was moved.
Implementations
Sourceimpl<'a> MoveContext<'a>
impl<'a> MoveContext<'a>