[][src]Struct script::dom::node::UnbindContext

pub struct UnbindContext<'a> {
    index: Cell<Option<u32>>,
    pub parent: &'a Node,
    prev_sibling: Option<&'a Node>,
    pub next_sibling: Option<&'a Node>,
    pub tree_connected: bool,
    pub tree_in_doc: bool,
}

The context of the unbinding from a tree of a node when one of its inclusive ancestors is removed.

Fields

index: Cell<Option<u32>>

The index of the inclusive ancestor that was removed.

parent: &'a Node

The parent of the inclusive ancestor that was removed.

prev_sibling: Option<&'a Node>

The previous sibling of the inclusive ancestor that was removed.

next_sibling: Option<&'a Node>

The next sibling of the inclusive ancestor that was removed.

tree_connected: bool

Whether the tree is connected.

tree_in_doc: bool

Whether the tree is in doc.

Implementations

impl<'a> UnbindContext<'a>[src]

pub fn new(
    parent: &'a Node,
    prev_sibling: Option<&'a Node>,
    next_sibling: Option<&'a Node>,
    cached_index: Option<u32>
) -> Self
[src]

Create a new UnbindContext value.

pub fn index(&self) -> u32[src]

The index of the inclusive ancestor that was removed from the tree.