[−][src]Struct script::dom::node::UnbindContext
The context of the unbinding from a tree of a node when one of its inclusive ancestors is removed.
Fields
index: Cell<Option<u32>>The index of the inclusive ancestor that was removed.
parent: &'a NodeThe parent of the inclusive ancestor that was removed.
prev_sibling: Option<&'a Node>The previous sibling of the inclusive ancestor that was removed.
next_sibling: Option<&'a Node>The next sibling of the inclusive ancestor that was removed.
tree_connected: boolWhether the tree is connected.
tree_in_doc: boolWhether the tree is in doc.
Implementations
impl<'a> UnbindContext<'a>[src]
pub fn new(
parent: &'a Node,
prev_sibling: Option<&'a Node>,
next_sibling: Option<&'a Node>,
cached_index: Option<u32>
) -> Self[src]
parent: &'a Node,
prev_sibling: Option<&'a Node>,
next_sibling: Option<&'a Node>,
cached_index: Option<u32>
) -> Self
Create a new UnbindContext value.
pub fn index(&self) -> u32[src]
The index of the inclusive ancestor that was removed from the tree.